==> CGAL-5.6.1-doc_html.tar.xz: doc_html/Optimal_transportation_reconstruction_2/group__PkgOptimalTransportationReconstruction2Classes.js <==
var group__PkgOptimalTransportationReconstruction2Classes =
[
    [ "Optimal_transportation_reconstruction_2", "classCGAL_1_1Optimal__transportation__reconstruction__2.html", [
      [ "FT", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a5a6558881ec7202b16384318605bb3c3", null ],
      [ "Point", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a8cbbcfc431de3be57cdc3cf986521dc1", null ],
      [ "Segment", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#ac7070d263cfc0776e18c6e2ac1a5e651", null ],
      [ "Optimal_transportation_reconstruction_2", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a6d945a9ddf0faa394e4d15e2e3e7b831", null ],
      [ "indexed_output", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a12a9e844d7231128492136405c421d65", null ],
      [ "list_output", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#ad94fc673df480c8b2076ae542fdd0e04", null ],
      [ "relocate_all_points", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#aec29a3302616e3b9975d4f3290af95e0", null ],
      [ "run", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#aa7a32398e56863507255a93294664bcf", null ],
      [ "run_under_wasserstein_tolerance", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#ada2cdd4244c0005d0527acdb68cb02cb", null ],
      [ "run_until", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a4da6cbf9c758cd7e04cd281f8bbd4960", null ],
      [ "set_random_sample_size", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#afd9b7e1ac33076cce2a7027c8857e511", null ],
      [ "set_relevance", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a9d13bdd2e76d4503e049728ee006e357", null ],
      [ "set_relocation", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a124dba5f9ea1fd561df35e499936679d", null ],
      [ "set_use_flip", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#ad491547e673dcbde076d68018e56ea8f", null ],
      [ "set_verbose", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a28260d575a16a1e351381016692ee14f", null ],
      [ "m_alpha", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a3c28d325eb5f428f43e706d073d2b093", null ],
      [ "m_dt", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a4af8bc9ee0f74fa258d0891b2add6fc1", null ],
      [ "m_ghost", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a58f887a13faf03c97bcbd37178d4120c", null ],
      [ "m_ignore", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a8018135d6110cf7e4d9ae4c72f8ae905", null ],
      [ "m_mchoice", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a2bfada5b599576d86ca83ba4aa2f3eda", null ],
      [ "m_mindex", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a6e911803fab5bc37df386173b5b4e91f", null ],
      [ "m_relocation", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#af0b7d350312bc77bd3d7a20223891834", null ],
      [ "m_samples", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a26f23478ff0f90cc0728ae4571cff6d5", null ],
      [ "m_tolerance", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a5e87eae7abf14365e35684d00ef18921", null ],
      [ "m_traits", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a0ef3805808558ea082ef24298c7c9286", null ],
      [ "m_use_flip", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a1d5fd670da81f8ff25e3e6ba5c20b1c0", null ],
      [ "m_verbose", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#ae23986053aebb5d4655aea4fd9d58dab", null ],
      [ "mass_pmap", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#ac8219d34e53daf0c96a27b1d308c9f3b", null ],
      [ "point_pmap", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a737669da7d8bcd0e6bdd053f6067b155", null ]
    ] ]
];

==> CGAL-6.1-doc_html.tar.xz: doc_html/Optimal_transportation_reconstruction_2/group__PkgOptimalTransportationReconstruction2Classes.js <==
var group__PkgOptimalTransportationReconstruction2Classes =
[
    [ "CGAL::Optimal_transportation_reconstruction_2< Traits, PointPMap, MassPMap >", "classCGAL_1_1Optimal__transportation__reconstruction__2.html", [
      [ "FT", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a5a6558881ec7202b16384318605bb3c3", null ],
      [ "Point", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a8cbbcfc431de3be57cdc3cf986521dc1", null ],
      [ "Segment", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#ac7070d263cfc0776e18c6e2ac1a5e651", null ],
      [ "Optimal_transportation_reconstruction_2", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a6d945a9ddf0faa394e4d15e2e3e7b831", null ],
      [ "indexed_output", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#ad95f5fe729b1e1eaf32d7137ed5434e9", null ],
      [ "list_output", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#ad94fc673df480c8b2076ae542fdd0e04", null ],
      [ "relocate_all_points", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#aec29a3302616e3b9975d4f3290af95e0", null ],
      [ "run", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#aa7a32398e56863507255a93294664bcf", null ],
      [ "run_under_wasserstein_tolerance", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#ada2cdd4244c0005d0527acdb68cb02cb", null ],
      [ "run_until", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a4da6cbf9c758cd7e04cd281f8bbd4960", null ],
      [ "set_random_sample_size", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#afd9b7e1ac33076cce2a7027c8857e511", null ],
      [ "set_relevance", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a9d13bdd2e76d4503e049728ee006e357", null ],
      [ "set_relocation", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a124dba5f9ea1fd561df35e499936679d", null ],
      [ "set_use_flip", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#ad491547e673dcbde076d68018e56ea8f", null ],
      [ "set_verbose", "classCGAL_1_1Optimal__transportation__reconstruction__2.html#a28260d575a16a1e351381016692ee14f", null ]
    ] ]
];
